#load library
library(raster) 

setwd("/Users/Norah/Dropbox/Caccone_Aksoy/Glossina-Mary/R-tools-patches/Saarmanetal2018_Gff_RasterLayers/")

########################################################################################################
#unzip folder and load raster files
FAO <- raster("FAO2001_HabitatSuitability.asc") #FAO map
PSN <- raster("Saarmanetal2018_PSNConnectivitySurface.asc") #PSN based connectivity surface
maxHS <- raster("Saarmanetal2018_MaxHabitatSuitability.asc")  #max of FAO and updated habitat suitability model
waterFull <- raster("UG_RiversLakes.asc") #raster format water of Uganda

########################################################################################################
#load other useful shapefiles
Uganda <- shapefile("UGA_adm0.dbf")
shape <- raster("UGA-northern-clip-shape.txt")
values(shape)[values(shape) == 0 ] = 1

########################################################################################################
# Compare different maps without cropping Uganda 
par(mfrow=c(3,1))
plot(FAO,main="FAO habitat suitability map from 2001", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
plot(PSN,main="PSN connectivity surface", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
plot(maxHS,main="Improved habitat suitability map", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
########################################################################################################

########################################################################################################
#crop each HS to Northern Uganda
FAOcrop <- crop(FAO,shape)
#rescale to 0 to 1
r <- FAOcrop
r.min = cellStats(r, "min")
r.max = cellStats(r, "max")
r.scale <- ((r - r.min) / (r.max - r.min))
FAOcrop <- r.scale
######################
PSNcrop <- crop(PSN,shape)
#rescale to 0 to 1
r <- PSNcrop
r.min = cellStats(r, "min")
r.max = cellStats(r, "max")
r.scale <- ((r - r.min) / (r.max - r.min))
PSNcrop <- r.scale
######################
maxHScrop <- crop(maxHS,shape)
#rescale to 0 to 1
r <- maxHScrop
r.min = cellStats(r, "min")
r.max = cellStats(r, "max")
r.scale <- ((r - r.min) / (r.max - r.min))
maxHScrop <- r.scale
##########


########################################################################################################
# Compare different maps after cropping to northern Uganda only
dev.off()
par(mfrow=c(3,1))
plot(FAOcrop,main="FAO habitat suitability map from 2001", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
plot(PSNcrop,main="PSN connectivity surface", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
plot(maxHScrop,main="Improved habitat suitability map", col=scaledColor, breaks=c(0,.1,.25,.5,.75,.9,.95,1))
plot(Uganda, add=T)
plot(waterFull,add=T,col="black",legend=F)
########################################################################################################

########################################################################################################
# to save a raster file, for example:
writeRaster(PSN, "Saarmanetal2018_PSNConnectivitySurface.asc", format = "ascii")
